@@ -176,19 +176,19 @@ impl DataBase {
     /// println!("{:?}", total_rows);
     /// ```
     pub fn get_total_rows(&self, table:String, condition:String) 
-    -> std::result::Result<i32, String>
+    -> i32
     {
         let mut sql = format!("SELECT COUNT(*) AS total FROM {}", table);
         if condition != "" { sql = format!("{} WHERE {}", sql, condition); }
 
         let result = self.sql(sql);
         if result.is_err() {
-            return Err(format!("{}", result.unwrap_err()));
+            return 0;
         }
 
         let result = result.unwrap();
         let total = result[0]["total"].as_i64().unwrap();
-        Ok(total as i32)
+        total as i32
     }
 
     /// # Example
