@@ -1,6 +1,6 @@
 pub mod utils;
 pub mod database;
 
-pub fn test(string:&str) -> &str{
+pub fn test_string(string:String) -> String{
     return string;
 }
\ No newline at end of file
